All of lore.kernel.org
 help / color / mirror / Atom feed
From: "Michael S. Tsirkin" <mst@redhat.com>
To: qemu-devel@nongnu.org
Cc: Peter Maydell <peter.maydell@linaro.org>,
	Jason Wang <jasowang@redhat.com>,
	Juan Quintela <quintela@redhat.com>
Subject: [PULL v2 23/65] failover: Rename bool to failover_primary_hidden
Date: Wed, 9 Dec 2020 13:08:20 -0500	[thread overview]
Message-ID: <20201209180546.721296-24-mst@redhat.com> (raw)
In-Reply-To: <20201209180546.721296-1-mst@redhat.com>

From: Juan Quintela <quintela@redhat.com>

You should not use passive naming variables.
And once there, be able to search for them.

Signed-off-by: Juan Quintela <quintela@redhat.com>
Message-Id: <20201118083748.1328-9-quintela@redhat.com>
Reviewed-by: Michael S. Tsirkin <mst@redhat.com>
Signed-off-by: Michael S. Tsirkin <mst@redhat.com>
---
 include/hw/virtio/virtio-net.h |  3 ++-
 hw/net/virtio-net.c            | 14 +++++++-------
 2 files changed, 9 insertions(+), 8 deletions(-)

diff --git a/include/hw/virtio/virtio-net.h b/include/hw/virtio/virtio-net.h
index c8da637d40..ca68be759f 100644
--- a/include/hw/virtio/virtio-net.h
+++ b/include/hw/virtio/virtio-net.h
@@ -207,7 +207,8 @@ struct VirtIONet {
     DeviceState *primary_dev;
     char *primary_device_id;
     char *standby_id;
-    bool primary_should_be_hidden;
+    /* primary failover device is hidden*/
+    bool failover_primary_hidden;
     bool failover;
     DeviceListener primary_listener;
     Notifier migration_state;
diff --git a/hw/net/virtio-net.c b/hw/net/virtio-net.c
index 3e82108d42..c221671852 100644
--- a/hw/net/virtio-net.c
+++ b/hw/net/virtio-net.c
@@ -916,7 +916,7 @@ static void virtio_net_set_features(VirtIODevice *vdev, uint64_t features)
 
     if (virtio_has_feature(features, VIRTIO_NET_F_STANDBY)) {
         qapi_event_send_failover_negotiated(n->netclient_name);
-        qatomic_set(&n->primary_should_be_hidden, false);
+        qatomic_set(&n->failover_primary_hidden, false);
         failover_add_primary(n, &err);
         if (err) {
             n->primary_dev = virtio_connect_failover_devices(n, &err);
@@ -3127,7 +3127,7 @@ static bool failover_replug_primary(VirtIONet *n, Error **errp)
         return false;
     }
     qdev_set_parent_bus(n->primary_dev, primary_bus, &error_abort);
-    qatomic_set(&n->primary_should_be_hidden, false);
+    qatomic_set(&n->failover_primary_hidden, false);
     hotplug_ctrl = qdev_get_hotplug_handler(n->primary_dev);
     if (hotplug_ctrl) {
         hotplug_handler_pre_plug(hotplug_ctrl, n->primary_dev, &err);
@@ -3148,7 +3148,7 @@ static void virtio_net_handle_migration_primary(VirtIONet *n,
     bool should_be_hidden;
     Error *err = NULL;
 
-    should_be_hidden = qatomic_read(&n->primary_should_be_hidden);
+    should_be_hidden = qatomic_read(&n->failover_primary_hidden);
 
     if (!n->primary_dev) {
         n->primary_dev = virtio_connect_failover_devices(n, &err);
@@ -3163,7 +3163,7 @@ static void virtio_net_handle_migration_primary(VirtIONet *n,
                                qdev_get_vmsd(n->primary_dev),
                                n->primary_dev);
             qapi_event_send_unplug_primary(n->primary_device_id);
-            qatomic_set(&n->primary_should_be_hidden, true);
+            qatomic_set(&n->failover_primary_hidden, true);
         } else {
             warn_report("couldn't unplug primary device");
         }
@@ -3213,8 +3213,8 @@ static int virtio_net_primary_should_be_hidden(DeviceListener *listener,
 
     n->primary_device_opts = device_opts;
 
-    /* primary_should_be_hidden is set during feature negotiation */
-    hide = qatomic_read(&n->primary_should_be_hidden);
+    /* failover_primary_hidden is set during feature negotiation */
+    hide = qatomic_read(&n->failover_primary_hidden);
 
     if (n->primary_device_dict) {
         g_free(n->primary_device_id);
@@ -3271,7 +3271,7 @@ static void virtio_net_device_realize(DeviceState *dev, Error **errp)
     if (n->failover) {
         n->primary_listener.should_be_hidden =
             virtio_net_primary_should_be_hidden;
-        qatomic_set(&n->primary_should_be_hidden, true);
+        qatomic_set(&n->failover_primary_hidden, true);
         device_listener_register(&n->primary_listener);
         n->migration_state.notify = virtio_net_migration_state_notifier;
         add_migration_state_change_notifier(&n->migration_state);
-- 
MST



  parent reply	other threads:[~2020-12-09 19:02 UTC|newest]

Thread overview: 70+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-12-09 18:06 [PULL v2 00/65] pc,pci,virtio: fixes, cleanups Michael S. Tsirkin
2020-12-09 18:06 ` [PULL v2 01/65] vhost-user-scsi: Fix memleaks in vus_proc_req() Michael S. Tsirkin
2020-12-09 18:06 ` [PULL v2 02/65] memory: Rename memory_region_notify_one to memory_region_notify_iommu_one Michael S. Tsirkin
2020-12-09 18:06 ` [PULL v2 03/65] memory: Add IOMMUTLBEvent Michael S. Tsirkin
2020-12-09 18:06 ` [PULL v2 04/65] memory: Add IOMMU_NOTIFIER_DEVIOTLB_UNMAP IOMMUTLBNotificationType Michael S. Tsirkin
2020-12-09 18:06 ` [PULL v2 05/65] intel_iommu: Skip page walking on device iotlb invalidations Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 06/65] memory: Skip bad range assertion if notifier is DEVIOTLB_UNMAP type Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 07/65] virtio: reset device on bad guest index in virtio_load() Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 08/65] acpi/gpex: Extract two APIs from acpi_dsdt_add_pci Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 09/65] fw_cfg: Refactor extra pci roots addition Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 10/65] hw/arm/virt: Write extra pci roots into fw_cfg Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 11/65] acpi: Extract crs build form acpi_build.c Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 12/65] acpi/gpex: Build tables for pxb Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 13/65] acpi: Align the size to 128k Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 14/65] unit-test: The files changed Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 15/65] unit-test: Add testcase for pxb Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 16/65] unit-test: Add the binary file and clear diff.h Michael S. Tsirkin
2020-12-09 18:07 ` [PULL v2 17/65] failover: fix indentantion Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 18/65] failover: Use always atomics for primary_should_be_hidden Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 19/65] failover: primary bus is only used once, and where it is set Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 20/65] failover: Remove unused parameter Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 21/65] failover: Remove external partially_hotplugged property Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 22/65] failover: qdev_device_add() returns err or dev set Michael S. Tsirkin
2020-12-09 18:08 ` Michael S. Tsirkin [this message]
2020-12-09 18:08 ` [PULL v2 24/65] failover: g_strcmp0() knows how to handle NULL Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 25/65] failover: Remove primary_device_opts Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 26/65] failover: remove standby_id variable Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 27/65] failover: Remove primary_device_dict Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 28/65] failover: Remove memory leak Michael S. Tsirkin
2020-12-09 18:08 ` [PULL v2 29/65] failover: simplify virtio_net_find_primary() Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 30/65] failover: should_be_hidden() should take a bool Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 31/65] failover: Rename function to hide_device() Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 32/65] failover: virtio_net_connect_failover_devices() does nothing Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 33/65] failover: Rename to failover_find_primary_device() Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 34/65] failover: simplify qdev_device_add() failover case Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 35/65] failover: simplify qdev_device_add() Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 36/65] failover: make sure that id always exist Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 37/65] failover: remove failover_find_primary_device() error parameter Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 38/65] failover: split failover_find_primary_device_id() Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 39/65] failover: We don't need to cache primary_device_id anymore Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 40/65] failover: Caller of this two functions already have primary_dev Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 41/65] failover: simplify failover_unplug_primary Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 42/65] failover: Remove primary_dev member Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 43/65] hw: add compat machines for 6.0 Michael S. Tsirkin
2020-12-09 18:09 ` [PULL v2 44/65] libvhost-user: replace qemu/bswap.h with glibc endian.h Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 45/65] libvhost-user: replace qemu/memfd.h usage Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 46/65] libvhost-user: remove qemu/compiler.h usage Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 47/65] libvhost-user: drop qemu/osdep.h dependency Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 48/65] libvhost-user: make it a meson subproject Michael S. Tsirkin
2020-12-10 16:09   ` Peter Maydell
2020-12-10 16:17     ` Paolo Bonzini
2020-12-10 16:26       ` Peter Maydell
2020-12-09 18:10 ` [PULL v2 49/65] libvhost-user: add a simple link test without glib Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 50/65] .gitlab-ci: add build-libvhost-user Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 51/65] contrib/vhost-user-blk: avoid g_return_val_if() input validation Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 52/65] contrib/vhost-user-gpu: " Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 53/65] contrib/vhost-user-input: " Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 54/65] block/export: " Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 55/65] hw/i386/pc: add max combined fw size as machine configuration option Michael S. Tsirkin
2020-12-09 18:10 ` [PULL v2 56/65] acpi: cpuhp: introduce 'firmware performs eject' status/control bits Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 57/65] x86: acpi: introduce AcpiPmInfo::smi_on_cpu_unplug Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 58/65] tests/acpi: allow expected files change Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 59/65] x86: acpi: let the firmware handle pending "CPU remove" events in SMM Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 60/65] tests/acpi: update expected files Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 61/65] x86: ich9: factor out "guest_cpu_hotplug_features" Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 62/65] x86: ich9: let firmware negotiate 'CPU hot-unplug with SMI' feature Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 63/65] pcie_aer: Fix help message of pcie_aer_inject_error command Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 64/65] hw/virtio-pci Added counter for pcie capabilities offsets Michael S. Tsirkin
2020-12-09 18:11 ` [PULL v2 65/65] hw/virtio-pci Added AER capability Michael S. Tsirkin
2020-12-09 21:42 ` [PULL v2 00/65] pc,pci,virtio: fixes, cleanups Peter Maydell

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20201209180546.721296-24-mst@redhat.com \
    --to=mst@redhat.com \
    --cc=jasowang@redhat.com \
    --cc=peter.maydell@linaro.org \
    --cc=qemu-devel@nongnu.org \
    --cc=quintela@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.